package brr

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Node.Wave_shaperSource

Wave shaper nodes.

Sourcemodule Oversample : sig ... end

Oversample type enumeration.

Sourcetype opts

The type for WaveShaperOptions.

Sourceval opts : ?channel_count:int -> ?channel_count_mode:Channel_count_mode.t -> ?channel_interpretation:Channel_interpretation.t -> ?curve:Brr.Tarray.float32 -> ?oversample:Oversample.t -> unit -> opts

opts () are wave shaper node options with given parameters.

Sourcetype t

The type for WaveShaperNode objects.

Sourceval create : ?opts:opts -> context -> t

create ~opts c creates a wave shaper node.

Sourceval as_node : t -> node

as_node n is n as an audio node.

Sourceval curve : t -> Brr.Tarray.float32 option

curve n is the curve of n.

Sourceval set_curve : t -> Brr.Tarray.float32 option -> unit

curve n v sets the curve of n to v.

Sourceval oversample : t -> Oversample.t

oversample n is the oversample of n.

Sourceval set_oversample : t -> Oversample.t -> unit

oversample n v sets the oversample of n to v.